@@ -38,8 +38,9 @@ use MIME::Base64 qw();
 use Net::SolarWinds::Log;
 use JSON qw();
 use URI::Encode qw(uri_encode);
+use POSIX qw(strftime);
 
-our $VERSION=1.13;
+our $VERSION=1.14;
 
 use base qw(Net::SolarWinds::ConstructorHash Net::SolarWinds::LogMethods Net::SolarWinds::Helper);
 use constant RESULT_CLASS=>'Net::SolarWinds::Result';
@@ -178,6 +179,44 @@ sub build_request {
   return $request;
 }
 
+=item * my $request=$self->NodeUnmanage($nodeID,$start,$end,$state);
+
+Used to manage and unmanage a node.
+
+Optional Arguments:
+  $start '11/18/2015 11:37:25'
+  $end '11/20/2015 11:37:25'
+  $state 
+    To Manage: JSON::false
+    To UnManage: JSON::true 
+
+Default interal values are
+
+  $start=now
+  $end=now + 10 years
+  $state=JSON::true
+
+=cut
+    
+sub NodeUnmanage {
+  my ($self,$nodeid,$start,$end,$state)=@_;
+  my $id='N:'.$nodeid;
+
+  my $format='%m/%d/%Y %H:%M:%S';
+  $start=strftime($format,localtime) unless defined($start);
+  unless(defined($end)) {
+    my $now=time;
+    # 10 years from now!
+    $now +=60 * 60 * 24 * 365 * 10;
+    $end=strftime($format,localtime) 
+  }
+  $state=JSON::true unless defined($state);
+  my $request=$self->build_request('POST','Invoke/Orion.Nodes/Unmanage',[$id,$start,$end,$state]);
+  my $result=$self->run_request($request);
+
+  return $result;
+}
+
 =item * my $result=$self->run_request($request);
 
 Takes a given HTTP::Request object and runs it returing a Net::SolarWinds::Result object.
